@@ -76,8 +76,8 @@ AcqFunctionCB = R6Class("AcqFunctionCB",
       constants = list(...)
       lambda  = constants$lambda
       p = self$surrogate$predict(xdt)
-      res = p$mean - self$surrogate_max_to_min * lambda * p$se
-      data.table(acq_cb = res)
+      cb = p$mean - self$surrogate_max_to_min * lambda * p$se
+      data.table(acq_cb = cb)
     }
   )
 )
